.. CUTLASS Python interface documentation master file, created by
   sphinx-quickstart on Mon Feb 13 17:57:39 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../../README.md
   :start-line: 1
   :parser: markdown

.. toctree::
   :hidden:

   Home <self>

.. toctree::
   :hidden:
   :caption: Getting Started:

   install.md
   Getting Started <externals/00_basic_gemm.nblink>
   contribute.md

.. toctree::
   :hidden:
   :caption: Python Documentation:

   modules.rst

.. toctree::
   :hidden:
   :caption: Examples and Tutorials:

   examples.rst

.. toctree::
   :hidden:
   :caption: Advanced:

.. toctree::
   :hidden:
   :caption: FAQ:

.. toctree::
   :hidden:
   :caption: Reference:

   Github <https://github.com/NVIDIA/cutlass>


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
